/****************************************************************************
 *
 * File: boatjet.inc
 * Date: 6.9.2005
 * Desc: Creates water jet around the boat.
 *
 * (c) Pterodon 2005
 *
 ****************************************************************************/



#include <inc\sc_global.h>



/* Maximum count of jets around the boat */
#define SC_BOATJET_MAX_NUM_JETS                     50
/* Maximum delay of jets before creating a new particle */
#define SC_BOATJET_MAX_DELAY                        0.5f
/* Particle ID for front jets */
#define SC_BOATJET_FRONT_JET_PTC_ID                 55
/* Particle ID for rear jets */
#define SC_BOATJET_REAR_JET_PTC_ID                  57
/* Minimal boat speed to emit particles from the jets */
#define SC_BOATJET_MIN_EMIT_SPEED                   1.0f
/* Coefficient for convertion from boat speed to particle scale */
#define SC_BOATJET_SCALE_COEFF                      0.02f
/* Maximal particle scale */
#define SC_BOATJET_MAX_PTC_SCALE                    0.5f


/* Minimal boat speed squared */
#define SC_BOATJET_MIN_EMIT_SPEED_SQUARED           (SC_BOATJET_MIN_EMIT_SPEED * SC_BOATJET_MIN_EMIT_SPEED)

/* Boat speed timer interval */
#define SC_BOAT_SPEED_INTERVAL                      0.5f



/****************************************************************************
 * Type: t_BOATJET_Jet
 * Desc: Contains data which are used for one water jet point on the boat
 */
typedef struct s_BOATJET_Jet
{
    sc_nod nod;     /* identifies nod, the jet belongs to */
    float delay;    /* time delay, at which this jet cannot emit the patricle */
    dword ptc_id;   /* particle ID for this jet */

} t_BOATJET_Jet;



/****************************************************************************
 * Data: g_BOATJET_BoatNod
 * Desc: Scene node of the boat
 */
static sc_nod g_BOATJET_BoatNod;

/****************************************************************************
 * Data: g_BOATJET_NumJets
 * Desc: Tells how many jets are around the boat
 */
static int g_BOATJET_NumJets;

/****************************************************************************
 * Data: g_BOATJET_LastPos
 * Desc: Last position of mass centre of the boat
 */
static c_Vector3 g_BOATJET_LastPos;

/****************************************************************************
 * Data: g_BOATJET_LastSpeed
 * Desc: Last last of mass centre of the boat
 */
static c_Vector3 g_BOATJET_LastSpeed;

/****************************************************************************
 * Data: g_BOATJET_SpeedTimer
 * Desc: updation timer for speed and position of mass centre of the boat
 */
static float     g_BOATJET_SpeedTimer;

/****************************************************************************
 * Data: g_BOATJET_JetList
 * Desc: List of all jets around the boat
 */
static t_BOATJET_Jet g_BOATJET_JetList[SC_BOATJET_MAX_NUM_JETS];



/****************************************************************************
 * Code: SC_BOATJET_ComputeDelay()
 * Desc: Computes random time delay for some jet in inteval
 *       <0.5 * SC_BOATJET_MAX_DELAY , SC_BOATJET_MAX_DELAY>
 */
float SC_BOATJET_ComputeDelay()
{
    return( 0.75f * SC_BOATJET_MAX_DELAY + 0.25f * frnd(SC_BOATJET_MAX_DELAY) );
}

/****************************************************************************
 * Code: SC_BOATJET_Initialize()
 * Desc: Enumerates all the jets around the boat and initializes them.
 *       Funcition always returns 0.
 */
int SC_BOATJET_Initialize(sc_nod bes_nod, sc_nod boat_nod)
{
    int i;
    char jet_name[100];
    sc_nod nod;
    s_SC_MarokObjState boat_state;

    /* remember nod of the boat */
    g_BOATJET_BoatNod = boat_nod;

    /* Make empty the jets list */
    g_BOATJET_NumJets = 0;

    /* Enumerate front jets */
    for (i = 1; g_BOATJET_NumJets < SC_BOATJET_MAX_NUM_JETS; g_BOATJET_NumJets++, i++)
    {
        /* search for jet nod */
        sprintf(jet_name,"front_jet_%d",i);
        if (0 == (nod = SC_NOD_GetNoMessage(bes_nod,jet_name)))
            break;

        /* inset jet to list of jets */
        g_BOATJET_JetList[g_BOATJET_NumJets].nod = nod;
        g_BOATJET_JetList[g_BOATJET_NumJets].delay = SC_BOATJET_ComputeDelay();
        g_BOATJET_JetList[g_BOATJET_NumJets].ptc_id = SC_BOATJET_FRONT_JET_PTC_ID;
    }

    /* Enumerate rear jets */
    for (i = 1; g_BOATJET_NumJets < SC_BOATJET_MAX_NUM_JETS; g_BOATJET_NumJets++, i++)
    {
        /* search for jet nod */
        sprintf(jet_name,"rear_jet_%d",i);
        if (0 == (nod = SC_NOD_GetNoMessage(bes_nod,jet_name)))
            break;

        /* inset jet to list of jets */
        g_BOATJET_JetList[g_BOATJET_NumJets].nod = nod;
        g_BOATJET_JetList[g_BOATJET_NumJets].delay = SC_BOATJET_ComputeDelay();
        g_BOATJET_JetList[g_BOATJET_NumJets].ptc_id = SC_BOATJET_REAR_JET_PTC_ID;
    }

    /* Get boat position */
    SC_Marok_GetState(g_BOATJET_BoatNod,&boat_state);
    g_BOATJET_LastPos = boat_state.placement.pos;
    g_BOATJET_LastSpeed.x = 0.0f;
    g_BOATJET_LastSpeed.y = 0.0f;
    g_BOATJET_LastSpeed.z = 0.0f;
    g_BOATJET_SpeedTimer = SC_BOAT_SPEED_INTERVAL;

    return(0);
}

/****************************************************************************
 * Code: SC_BOATJET_Release()
 * Desc: Releases all jets and returns 0.
 */
int SC_BOATJET_Release()
{
    g_BOATJET_NumJets = 0;
    return(0);
}

/****************************************************************************
 * Code: SC_BOATJET_EmitJetPtc()
 * Desc: Emits a particle from the jet, if possible, setups new delay
 *       and returns 0.
 */
int SC_BOATJET_EmitJetPtc(t_BOATJET_Jet *jet, float speed)
{
    /* Check boat speed against the limit */
    if (speed >= SC_BOATJET_MIN_EMIT_SPEED_SQUARED)
    {
        float scale;

        /* compute scale for the particle */
        scale = SC_BOATJET_SCALE_COEFF * (speed - SC_BOATJET_MIN_EMIT_SPEED_SQUARED);
        if (scale > SC_BOATJET_MAX_PTC_SCALE)
            scale = SC_BOATJET_MAX_PTC_SCALE;

        /* Emit a particle */
        SC_CreatePtcInNodSpace_Ext(jet->ptc_id,jet->nod,0.0f,0.0f,scale,1.0f);
    }

    /* Compute new time delay for the jet */
    jet->delay = SC_BOATJET_ComputeDelay();

    return(0);
}

/****************************************************************************
 * Code: SC_BOATJET_TimeStep()
 * Desc: Updates all the jets of the boat by specified time and returns 0.
 */
int SC_BOATJET_TimeStep(float time_step)
{
    if (g_BOATJET_NumJets > 0)
    {
        int i;
        float speed;
        s_SC_MarokObjState boat_state;

        g_BOATJET_SpeedTimer -= time_step;
        if (g_BOATJET_SpeedTimer <= 0.0f)
        {
            /* get boat motion */
            SC_Marok_GetState(g_BOATJET_BoatNod,&boat_state);

            /* Compute the boat velocity */
            g_BOATJET_LastSpeed.x = (boat_state.placement.pos.x - g_BOATJET_LastPos.x) / time_step;
            g_BOATJET_LastSpeed.y = (boat_state.placement.pos.y - g_BOATJET_LastPos.y) / time_step;
            g_BOATJET_LastSpeed.z = (boat_state.placement.pos.z - g_BOATJET_LastPos.z) / time_step;

            /* Store current boat position */
            g_BOATJET_LastPos = boat_state.placement.pos;

            /* Reset speed timer */
            g_BOATJET_SpeedTimer = SC_BOAT_SPEED_INTERVAL;
        }

        /* Compute the boat speed */
        speed = (g_BOATJET_LastSpeed.x * g_BOATJET_LastSpeed.x) +
                (g_BOATJET_LastSpeed.y * g_BOATJET_LastSpeed.y) +
                (g_BOATJET_LastSpeed.z * g_BOATJET_LastSpeed.z);

        /* cross all jets and update them */
        for (i = 0; i < g_BOATJET_NumJets; i++)
        {
            g_BOATJET_JetList[i].delay -= time_step;
            if (g_BOATJET_JetList[i].delay <= 0.0f)
                SC_BOATJET_EmitJetPtc(g_BOATJET_JetList + i,speed);
        }
    }

    return(0);
}
