//------------------------------------------------------------------
//---
//--- File: bas0_b2.fx
//---
//--- Desc: Vertex lighting and blending of blocks (1 weight)
//---


//------------------------------------------------------------------
//--- GLOBAL VARIABLES ---------------------------------------------
//------------------------------------------------------------------

//--- transformations ----------------------------------------------
float4x4 World : WORLD;     // world matrix
float4x4 View : VIEW;
float4x4 Projection : PROJECTION;

//--- local space vertex blending matrices -------------------------
float4x4 World1;            // local space vertex blending matrix 1
float4x4 World2;            // local space vertex blending matrix 2

//--- directional light properties ---------------------------------
float3 dl_dir;
float3 dl_dif;
float3 dl_amb;

//--- Omni lights properties ---------------------------------------
float4  omni0_dif,omni0_loc,omni0_var;
float4  omni1_dif,omni1_loc,omni1_var;
float4  omni2_dif,omni2_loc,omni2_var;
float4  omni3_dif,omni3_loc,omni3_var;
float4  omni4_dif,omni4_loc,omni4_var;
float4  omni5_dif,omni5_loc,omni5_var;
float4  omni6_dif,omni6_loc,omni6_var;

//--- block alpha --------------------------------------------------
float g_alpha;

//--- scene fog properties -----------------------------------------
float fog_idelta;
float fog_end;

//--- texture sampler ----------------------------------------------
sampler gTextureSampler : register(s0);


//------------------------------------------------------------------
float3 ComputeOmniLightColor(
                float3 VertexPos,
                float3 VertexNormal,
                
                float3 LightPos,
                float3 LightColor,
                float  LightRange,
                float  LightCoefC,
                float  LightCoefL
                )
{
    float3 dstColor = 0;

    float3 LightDirScaled = (VertexPos - LightPos) / LightRange;
    float DirectionFactor = saturate(dot(normalize(LightDirScaled),VertexNormal));
    if (DirectionFactor > 0.0f)
    {
        float AttenuationLfactor = 1.0f - dot(LightDirScaled,LightDirScaled);
        if (AttenuationLfactor >= 0.0f)
            dstColor += LightColor * (DirectionFactor * (AttenuationLfactor * LightCoefL + LightCoefC));
    }

    return dstColor;
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 0L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_0L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_0L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_0L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_0L();
        PixelShader = compile ps_1_4 EffectPixelShader_0L();
    }
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 1L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_1L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // apply omni light color
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni0_loc,omni0_dif,omni0_var.x,omni0_var.y,omni0_var.z);

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_1L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_1L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_1L();
        PixelShader = compile ps_1_4 EffectPixelShader_1L();
    }
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 2L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_2L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // apply omni light color
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni0_loc,omni0_dif,omni0_var.x,omni0_var.y,omni0_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni1_loc,omni1_dif,omni1_var.x,omni1_var.y,omni1_var.z);

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_2L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_2L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_2L();
        PixelShader = compile ps_1_4 EffectPixelShader_2L();
    }
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 3L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_3L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // apply omni light color
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni0_loc,omni0_dif,omni0_var.x,omni0_var.y,omni0_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni1_loc,omni1_dif,omni1_var.x,omni1_var.y,omni1_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni2_loc,omni2_dif,omni2_var.x,omni2_var.y,omni2_var.z);

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_3L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_3L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_3L();
        PixelShader = compile ps_1_4 EffectPixelShader_3L();
    }
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 4L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_4L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // apply omni light color
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni0_loc,omni0_dif,omni0_var.x,omni0_var.y,omni0_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni1_loc,omni1_dif,omni1_var.x,omni1_var.y,omni1_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni2_loc,omni2_dif,omni2_var.x,omni2_var.y,omni2_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni3_loc,omni3_dif,omni3_var.x,omni3_var.y,omni3_var.z);

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_4L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_4L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_4L();
        PixelShader = compile ps_1_4 EffectPixelShader_4L();
    }
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 5L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_5L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // apply omni light color
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni0_loc,omni0_dif,omni0_var.x,omni0_var.y,omni0_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni1_loc,omni1_dif,omni1_var.x,omni1_var.y,omni1_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni2_loc,omni2_dif,omni2_var.x,omni2_var.y,omni2_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni3_loc,omni3_dif,omni3_var.x,omni3_var.y,omni3_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni4_loc,omni4_dif,omni4_var.x,omni4_var.y,omni4_var.z);

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_5L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_5L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_5L();
        PixelShader = compile ps_1_4 EffectPixelShader_5L();
    }
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 6L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_6L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // apply omni light color
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni0_loc,omni0_dif,omni0_var.x,omni0_var.y,omni0_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni1_loc,omni1_dif,omni1_var.x,omni1_var.y,omni1_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni2_loc,omni2_dif,omni2_var.x,omni2_var.y,omni2_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni3_loc,omni3_dif,omni3_var.x,omni3_var.y,omni3_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni4_loc,omni4_dif,omni4_var.x,omni4_var.y,omni4_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni5_loc,omni5_dif,omni5_var.x,omni5_var.y,omni5_var.z);

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_6L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_6L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_6L();
        PixelShader = compile ps_1_4 EffectPixelShader_6L();
    }
}


//------------------------------------------------------------------
//--- EFFECT DEFINITION - 7L ---------------------------------------
//------------------------------------------------------------------

//--- vertex shader of this effect ---------------------------------
void EffectVertexShader_7L(
        in  float3 srcPosition : POSITION,
        in  float3 srcNormal   : NORMAL,
        in  float2 srcWeight   : BLENDWEIGHT,   // but not used here
        in  float2 srcTexUV    : TEXCOORD0,

        out float4 dstPosition : POSITION,
        out float2 dstTexUV    : TEXCOORD0,
        out float3 dstColor    : TEXCOORD1,
        out float  dstFog      : FOG
        )
{
    // compute world space position of vertex
	float3 WorldSpacePos = mul(mul(float4(srcPosition,1),World1) * srcWeight[0] +
	                           mul(float4(srcPosition,1),World2) * srcWeight[1],
	                           World);

    // compute camera space position of vertex
    float3 CameraSpacePos = mul(float4(WorldSpacePos,1),View);
    
    // compute normal vector in world space
	float3 WorldNormal = normalize(mul(mul(srcNormal,(float3x3)World1) * srcWeight[0] +
	                                   mul(srcNormal,(float3x3)World2) * srcWeight[1],
                                       (float3x3)World));
    
    // compute camera projection space position of vertex
    dstPosition = mul(float4(CameraSpacePos,1),Projection);

    // send texture coordinates
    dstTexUV = srcTexUV;

    // compute vertex lighting color for directional light
    dstColor = dl_amb + saturate(dot(WorldNormal,-dl_dir)) * dl_dif;

    // apply omni light color
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni0_loc,omni0_dif,omni0_var.x,omni0_var.y,omni0_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni1_loc,omni1_dif,omni1_var.x,omni1_var.y,omni1_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni2_loc,omni2_dif,omni2_var.x,omni2_var.y,omni2_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni3_loc,omni3_dif,omni3_var.x,omni3_var.y,omni3_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni4_loc,omni4_dif,omni4_var.x,omni4_var.y,omni4_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni5_loc,omni5_dif,omni5_var.x,omni5_var.y,omni5_var.z);
    dstColor += ComputeOmniLightColor(WorldSpacePos,-WorldNormal,omni6_loc,omni6_dif,omni6_var.x,omni6_var.y,omni6_var.z);

    // compute vertex fog
    dstFog = fog_idelta * (fog_end - CameraSpacePos.z);
}

//--- pixel shader of this effect ----------------------------------
void EffectPixelShader_7L(
        in  float2 srcTexUV  : TEXCOORD0,
        in  float3 srcColor  : TEXCOORD1,

        out float4 dstColor  : COLOR
        )
{
    // compute pixel color
    dstColor = tex2D(gTextureSampler,srcTexUV) * float4(srcColor,g_alpha);
}

//--- effect definition --------------------------------------------
technique tech_7L
{
    pass FirstAndLast
    {
        VertexShader = compile vs_2_0 EffectVertexShader_7L();
        PixelShader = compile ps_1_4 EffectPixelShader_7L();
    }
}
